@@ -1,7 +1,7 @@
 package Sort::Sub::naturally;
 
-our $DATE = '2016-02-27'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-04-06'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010;
 use strict;
@@ -29,10 +29,10 @@ sub gen_sorter {
         for (@a_parts) {
             last if $i >= @b_parts;
             #say "D:$a_parts[$i] <=> $b_parts[$i]";
-            if ($a_parts[$i] =~ /\d/ || $b_parts[$i] =~ /\d/) {
-                $cmp = $a_parts[$i] <=> $b_parts[$i];
-            } else {
+            if ($a_parts[$i] =~ /\D/ || $b_parts[$i] =~ /\D/) {
                 $cmp = $a_parts[$i] cmp $b_parts[$i];
+            } else {
+                $cmp = $a_parts[$i] <=> $b_parts[$i];
             }
             last if $cmp;
             $i++;
@@ -56,7 +56,7 @@ Sort::Sub::naturally - Sort naturally
 
 =head1 VERSION
 
-This document describes version 0.05 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2016-02-27.
+This document describes version 0.06 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2016-04-06.
 
 =for Pod::Coverage ^(gen_sorter)$
 
